import { Contract, PopulatedTransaction } from '@ethersproject/contracts';
import { NonceManager } from '@ethersproject/experimental';
import { OrderParams, StarkMethodParams, Token, Transaction, TransferParams } from '@imtbl/imx-link-types';
import * as TE from 'fp-ts/lib/TaskEither';
/**
 * Immutable X Controller
 */
export declare class ImmutableXController {
    private signer;
    private accountMappingKey;
    private accountMapping;
    private activeKeyPair;
    private store;
    constructor(signer: NonceManager, accountMappingKey?: string);
    getAddress(): Promise<string>;
    get starkPublicKey(): string | undefined;
    getStarkPublicKey(path?: string): Promise<string>;
    getExchangeContract(contractAddress: string, nftFlag?: boolean): Contract;
    sign(payload: any): Promise<string>;
    signStark(payload: any): Promise<string>;
    signRegistration(): Promise<string>;
    /**
     * StarkWare JSON-RPC Spec
     */
    account(layer: string, application: string, index: string): Promise<string>;
    signUserRegistration(etherKey: string, starkPublicKey: string, nonce: string): Promise<string>;
    signDeposit(starkPublicKey: string, vaultId: string, token: Token, quantizedAmount: string, nonce: string): Promise<string>;
    signWithdraw(starkPublicKey: string, vaultId: string, token: Token, quantizedAmount: string, nonce: string): Promise<string>;
    transfer(from: TransferParams, to: TransferParams, token: Token, quantizedAmount: string, nonce: string, expirationTimestamp: string): Promise<string>;
    createOrder(starkPublicKey: string, sell: OrderParams, buy: OrderParams, nonce: string, expirationTimestamp: string): Promise<string>;
    register(contractAddress: string, etherKey: string, starkPublicKey: string, operatorSignature: string): Promise<Transaction>;
    depositF({ contractAddress, starkPublicKey, quantizedAmount, token, vaultId, }: StarkMethodParams.StarkDepositParams): TE.TaskEither<Error, PopulatedTransaction>;
    deposit(params: StarkMethodParams.StarkDepositParamsTS): Promise<Transaction>;
    depositCancel(contractAddress: string, starkPublicKey: string, token: Token, vaultId: string): Promise<Transaction>;
    depositReclaim(contractAddress: string, starkPublicKey: string, token: Token, vaultId: string): Promise<Transaction>;
    withdrawal(contractAddress: string, starkPublicKey: string, token: Token): Promise<Transaction>;
    fullWithdrawal(contractAddress: string, starkPublicKey: string, vaultId: string): Promise<Transaction>;
    freeze(contractAddress: string, starkPublicKey: string, vaultId: string): Promise<Transaction>;
    verifyEscape(contractAddress: string, starkPublicKey: string, proof: string[]): Promise<Transaction>;
    escape(contractAddress: string, starkPublicKey: string, vaultId: string, token: Token, quantizedAmount: string): Promise<Transaction>;
    mintNFT(nftContractAddress: string, to: string, tokenId: string, tokenUri: string): Promise<Transaction>;
    approveNFTF({ nftContractAddress, contractAddress, tokenId, }: StarkMethodParams.StarkApproveNFTParams): TE.TaskEither<Error, Transaction>;
    approveNFT(params: StarkMethodParams.StarkApproveNFTParamsTS): Promise<Transaction>;
    private assertStarkPublicKey;
    private getActiveKeyPair;
    private setActiveKeyPair;
    private getKeyPairFromPath;
    private getAccountMapping;
}
export default ImmutableXController;
//# sourceMappingURL=index.d.ts.map